/***************************************************************************
 *   kdeeduplottest.cpp                                                    *
 *   ------------------                                                    *
 *   A test program for the KDE EDU Plot library.                          *
 *                                                                         *
 *   Copyright (C) 2005 by Andreas Nicolai                                 *
 *   Andreas.Nicolai@gmx.net                                               *
 *                                                                         *
 *   This program is free software; you can redistribute it and/or modify  *
 *   it under the terms of the GNU General Public License as published by  *
 *   the Free Software Foundation; either version 2 of the License, or     *
 *   (at your option) any later version.                                   *
 *                                                                         *
 ***************************************************************************/

// -------------------------------------------------------------------------
// You need to setup a few things in KDevelop in order to use the plot 
// widget. 
// First add the library kdeeduplot to the external libraries:
// - open the "Automake Manager" and the program (target) options
// - select the "Libraries" tab and add the library (enter the 
//   text "-lkdeeduplot" in the edit line after clicking "Add").
// Then add the kdeedu directory as include directory or use, as in this 
// example a relative path to the plot widget.
// -------------------------------------------------------------------------

#include "kdeeduplottest.h"
#include "kdeeduplottest.moc"

#include <qlayout.h>
#include <qlabel.h>

#include <kmainwindow.h>
#include <klocale.h>
#include <kdebug.h>

// here we include the plot library
#include "../../kdeedu/libkdeedu/kdeeduplot/kplotwidget.h"

KdeEduPlotTest::KdeEduPlotTest()
    : KMainWindow( 0, "KDE-EDU Plot Test" )
{
	// Create a simple vertical layout that belongs to the main window.
	QVBoxLayout *vlay = new QVBoxLayout( this, 0, 0 );
	// Create a plot widget that also belongs to the main window
	// The constructor arguments are the min/max units for the x and y units respectively.
	KPlotWidget * pw = new KPlotWidget( 0.0, 1.0, 0.0, 1.0, this );
	// Finally add the plot widget to the layout.
	vlay->addWidget( pw );

	// Now we customize the plot a bit (see member function documentation)
	pw->setShowGrid( false ); // no grid please
	pw->setBGColor( QColor( "white" ) );
	pw->setFGColor( QColor( "black" ) );
	pw->setLimits( 0.0, 120.0, 0.0, 240.0 );
	pw->setLeftPadding(60);
	pw->setXAxisLabel( i18n( "Time in [s]" ) );
	pw->setYAxisLabel( i18n( "Distance in [m]" ) );
	resize( 500, 400 );
	
	// Create plot object
	KPlotObject * ob = new KPlotObject(	"My line", "red", KPlotObject::CURVE, 2, KPlotObject::SOLID);
	// Add plot object to chart
	pw->addObject(ob);
	// Add some random points to the plot object
	double s = 0;
	srand(time(NULL));
	ob->addPoint( DPoint(0, 0) );
	for (unsigned int i=5; i<=120; i += 5) {
		s += rand()*0.2*(240.0 - s)/RAND_MAX;
		ob->addPoint( DPoint(i, s) );
		//kdDebug() << "Adding point [" << i << "," << s << "]" << endl;
	}
}	

